<?php
/**
 * Plugin Name:       Donation Block
 * Plugin URI:        #
 * Description:       Create PayPal donation button using gutenberg block.
 * Version:           1.0.0
 * Author:            wpcodelibrary
 * Author URI:        http://www.wpcodelibrary.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       donation-block
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Function is used to register donation block
 *
 * @sicne 1.0.0
 *
 */

function donation_block_init() {
	// Register our block editor script.
	wp_register_script( 'donation-block', plugins_url( 'block.build.js', __FILE__ ), array( 'wp-blocks', 'wp-element', 'wp-components', 'wp-editor' ) );
	$admin_email = get_option( 'admin_email' );
	// Register our block, and explicitly define the attributes we accept.
	register_block_type( 'gbdb/donation-block', array(
		'attributes'      => [
			'email'    => [
				'default' => $admin_email,
			],
			'amount'   => [
				'default' => 10.00,
			],
			'currency' => [
				'default' => 'USD',
			],
			'purpose'  => [
				'default' => 'Charity for Child Health Care',
			],

		],
		'editor_script'   => 'donation-block', // The script name we gave in the wp_register_script() call.
		'render_callback' => 'gbdb_donation_block_render',
	) );

}

add_action( 'init', 'donation_block_init' );

/**
 * @param $atts donation button attributes
 *
 * @return donation shortcode string
 */
function gbdb_donation_block_render( $atts ) {
	return "[gbdonation_button email =" . $atts['email'] . " amount =" . $atts['amount'] . " currency=" . $atts['currency'] . " purpose=" . $atts['purpose'] . "]";
}

/**
 * Function is used to create shortcode.
 *
 * @since 1.0.0
 *
 */
add_shortcode( 'gbdonation_button', 'gbdb_shortcode_html_callback' );

function gbdb_shortcode_html_callback( $atts ) {
	$admin_email = get_option( 'admin_email' );
	$atts        = shortcode_atts( array(
		'email'    => $admin_email,
		'currency' => 'USD',
		'purpose'  => '',
		'amount'   => '',
		'size'     => 'large',
	), $atts, 'bartag' );


	switch ( $atts['size'] ) {
		case 'small':
			$imgurl = 'https://www.paypal.com/en_US/i/btn/btn_donate_SM.gif';
			break;
		case 'medium':
			$imgurl = 'https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif';
			break;
		case 'large':
			$imgurl = 'https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif';
			break;
		default:
			$imgurl = 'https://www.paypal.com/en_US/i/btn/btn_donate_SM.gif';
	}

	return '<form  target="_blank" action="https://www.paypal.com/cgi-bin/webscr" method="post">
    			<div class="gbdb_donation_button">
			        <input type="hidden" name="cmd" value="_donations">
                                <input type="hidden" name="item_name" value="' . $atts['purpose'] . '">
                                <input type="hidden" name="amount" value="' . $atts['amount'] . '">
			        <input type="hidden" name="business" value="' . $atts['email'] . '">
			        <input type="hidden" name="rm" value="0">
			        <input type="hidden" name="currency_code" value="' . $atts['currency'] . '">
					<input name="bn" value="WPCodelibrary_SP_EC_PRO" type="hidden">
			        <input type="image" src="' . $imgurl . '" name="submit" alt="PayPal - The safer, easier way to pay online.">
			        <img alt="" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="1" height="1">
			    </div>
			</form>';
}